@@ -53,8 +53,9 @@ module Database.Record.TH (
 
   -- * Templates about record type name
   NameConfig,  defaultNameConfig,
+  recordTypeName, columnName,
 
-  recordTypeName, recordType,
+  recordType,
 
   columnOffsetsVarNameDefault,
 
@@ -109,7 +110,8 @@ data NameConfig =
 instance Show NameConfig where
   show = const "<nameConfig>"
 
--- | Default implementation of 'NameConfig' type
+-- | Default implementation of 'NameConfig' type.
+--   To customize this, use record update syntax.
 defaultNameConfig :: NameConfig
 defaultNameConfig =
   NameConfig
